@@ -31,6 +31,8 @@
 #ifndef __NAUTILUS_ACTIONS_API_NA_GCONF_MONITOR_H__
 #define __NAUTILUS_ACTIONS_API_NA_GCONF_MONITOR_H__
 
+#ifdef HAVE_GCONF
+#ifndef NA_DISABLE_DEPRECATED
 /**
  * SECTION: gconf-monitor
  * @title: NAGConfMonitor
@@ -40,20 +42,23 @@
  * This class manages the GConf monitoring.
  * It is used to monitor both the GConf provider and the GConf runtime
  * preferences.
+ *
+ * Starting with Nautilus-Actions 3.1.0, GConf, whether it is used as a
+ * preference storage subsystem or as an I/O provider, is deprecated.
  */
 
 #include <gconf/gconf-client.h>
 
 G_BEGIN_DECLS
 
-#define NA_GCONF_MONITOR_TYPE                  ( na_gconf_monitor_get_type())
-#define NA_GCONF_MONITOR( object )             ( G_TYPE_CHECK_INSTANCE_CAST( object, NA_GCONF_MONITOR_TYPE, NAGConfMonitor ))
-#define NA_GCONF_MONITOR_CLASS( klass )        ( G_TYPE_CHECK_CLASS_CAST( klass, NA_GCONF_MONITOR_TYPE, NAGConfMonitorClass ))
-#define NA_IS_GCONF_MONITOR( object )          ( G_TYPE_CHECK_INSTANCE_TYPE( object, NA_GCONF_MONITOR_TYPE ))
-#define NA_IS_GCONF_MONITOR_CLASS( klass )     ( G_TYPE_CHECK_CLASS_TYPE(( klass ), NA_GCONF_MONITOR_TYPE ))
-#define NA_GCONF_MONITOR_GET_CLASS( object )   ( G_TYPE_INSTANCE_GET_CLASS(( object ), NA_GCONF_MONITOR_TYPE, NAGConfMonitorClass ))
+#define NA_GCONF_MONITOR_TYPE                ( na_gconf_monitor_get_type())
+#define NA_GCONF_MONITOR( object )           ( G_TYPE_CHECK_INSTANCE_CAST( object, NA_GCONF_MONITOR_TYPE, NAGConfMonitor ))
+#define NA_GCONF_MONITOR_CLASS( klass )      ( G_TYPE_CHECK_CLASS_CAST( klass, NA_GCONF_MONITOR_TYPE, NAGConfMonitorClass ))
+#define NA_IS_GCONF_MONITOR( object )        ( G_TYPE_CHECK_INSTANCE_TYPE( object, NA_GCONF_MONITOR_TYPE ))
+#define NA_IS_GCONF_MONITOR_CLASS( klass )   ( G_TYPE_CHECK_CLASS_TYPE(( klass ), NA_GCONF_MONITOR_TYPE ))
+#define NA_GCONF_MONITOR_GET_CLASS( object ) ( G_TYPE_INSTANCE_GET_CLASS(( object ), NA_GCONF_MONITOR_TYPE, NAGConfMonitorClass ))
 
-typedef struct _NAGConfMonitorPrivate NAGConfMonitorPrivate;
+typedef struct _NAGConfMonitorPrivate        NAGConfMonitorPrivate;
 
 typedef struct {
 	/*< private >*/
@@ -62,7 +67,7 @@ typedef struct {
 }
 	NAGConfMonitor;
 
-typedef struct _NAGConfMonitorClassPrivate NAGConfMonitorClassPrivate;
+typedef struct _NAGConfMonitorClassPrivate   NAGConfMonitorClassPrivate;
 
 typedef struct {
 	/*< private >*/
@@ -79,4 +84,6 @@ void            na_gconf_monitor_release_monitors( GList *monitors );
 
 G_END_DECLS
 
+#endif /* NA_DISABLE_DEPRECATED */
+#endif /* HAVE_GCONF */
 #endif /* __NAUTILUS_ACTIONS_API_NA_GCONF_MONITOR_H__ */
